﻿# set variables
$backupDate   = Get-Date -UFormat "%Y-%m-%d_%H%M"
$basePath     = "F:\backup"
$backupFile   = "$basePath\MongoDB_$backupDate.gz"
$backupShare  = "\\<server>\backup"

# retention period in days
$retention    = 14 

# MongoDB instance to be backed up
$dbhost       = "localhost:27017"

# determine version of MongoDB in use
$mongo        = (Get-WmiObject win32_service | ? name -EQ "SoftwareIDM.IdentityPanelDB").PathName
$dbver        = $mongo.split('\')[4]
$dbroot       = "C:\Program Files\MongoDB\Server"
$mongodump    = "$dbroot\$dbver\bin\mongodump.exe"
$mongorestore = "$dbroot\$dbver\bin\mongorestore.exe"

# create database archive
$backupcmd = "& '$mongodump' --host $dbhost --archive=$backupFile --gzip --quiet"
Invoke-Expression $backupcmd

# remove archives older than two weeks
Get-ChildItem -Path $backupShare -Filter *.gz | Where CreationTime -lt  (Get-Date).AddDays(-$retention) | Remove-Item -Confirm:$false

# move new backup to share
try { Copy-Item $backupFile -Destination $backupShare
      Remove-Item -Path $backupFile }
catch { Write-Host "Transfer of $backupFile to $backupShare failed" }

## example restore command
# $restorecmd = "& '$mongorestore' --dryRun --host $dbhost --gzip --archive=$backupFile --verbose"
# Invoke-Expression $restorecmd 